var otb_optionsDataBoolean = new Array();
var otb_optionsDataInteger = new Array();
var otb_optionsDataString  = new Array();
var otb_description = null;
var otb_signature   = null;

function otb_saveOptions() { // Saves the user's options
    const preferencesService = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("");
    const string             = Components.classes["@mozilla.org/supports-string;1"].createInstance(Components.interfaces.nsISupportsString);

    var option      = null;
    var optionValue = null;

    otb_storeOptions();    // Make sure current page is stored

    for(option in otb_optionsDataBoolean) { // Loop through the boolean options
        preferencesService.setBoolPref(option, otb_optionsDataBoolean[option]);
    }

    for(option in otb_optionsDataInteger) { // Loop through the integer options
        optionValue = otb_optionsDataInteger[option];
		if(optionValue) { preferencesService.setIntPref(option, optionValue);  } // If the option value is set
	    else if(preferencesService.prefHasUserValue(option)) { preferencesService.clearUserPref(option); }
    }

    for(option in otb_optionsDataString) { // Loop through the string options
        optionValue = otb_optionsDataString[option];
        if(optionValue || preferencesService.prefHasUserValue(option)) { // If the option value is set or the preference currently has a value
            string.data = optionValue;
            preferencesService.setComplexValue(option, Components.interfaces.nsISupportsString, string);
        }
    }
} // end otb_saveOptions()

function otb_storeOptions() { // Stores the user's options to be saved later
    const iFrame       = document.getElementById("otb-options-iframe");
    const iFrameSrc    = iFrame.getAttribute("src");
    const pageDocument = iFrame.contentDocument;

    if(iFrameSrc.indexOf("general") != -1) {   // If this is the general page
        // otb_optionsDataBoolean["otb.menu.hide"]     = pageDocument.getElementById("otb.menu.hide").checked;
    }
    else if(iFrameSrc.indexOf("signatures") != -1) {
        const preferencesService = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("");
        const otb_sigListbox       = pageDocument.getElementById("otb_sigListbox");

        var description    = null;
		var signature      = null;
        var signatureCount = 0;
	    var listItem         = null;

        // If the signatures count preference is set
        if(preferencesService.prefHasUserValue("otb.singatures.count")) { signatureCount = preferencesService.getIntPref("otb.singatures.count"); }

        for(var i = 1; i <= signatureCount; i++)  { // Loop through the previous signatures
            description = "otb.opt.sig." + i + ".description";
            signature   = "otb.opt.sig." + i + ".signature";
            otb_optionsDataString[description] = "";
            otb_optionsDataString[signature]   = ""; }

		signatureCount = otb_sigListbox.getRowCount();
        for(i = 1; i <= signatureCount; i++)  {  // Loop through the possible signatures
            description = "otb.opt.sig." + i + ".description";
            signature   = "otb.opt.sig." + i + ".signature";
            listItem    = otb_sigListbox.getItemAtIndex(i - 1);
            otb_optionsDataString[description] = listItem.label.trim();
            otb_optionsDataString[signature]   = listItem.value.trim();
        }
        otb_optionsDataInteger["otb.singatures.count"] = signatureCount;
    }
} // end otb_storeOptions()

function otb_changePage(pageList) { // Handles changing the options page
    otb_storeOptions();
    document.getElementById("otb-options-iframe").setAttribute("src", pageList.selectedItem.getAttribute("value"));
} // end otb_changePage()

function otb_addSignature() { // Adds a signature
    const pageDocument = document.getElementById("otb-options-iframe").contentDocument;
    const otb_sigListbox = pageDocument.getElementById("otb_sigListbox");

    window.openDialog("chrome://orkutbar/content/options/dlg_signature.xul", "otb-signature-dialog", "centerscreen,chrome,modal", "add");

    if(otb_description) { // If the description is set
        var newItem = otb_sigListbox.appendItem(otb_description, otb_signature);
        otb_sigListbox.ensureElementIsVisible(newItem);
        otb_sigListbox.selectItem(newItem);
    }
}

function otb_deleteSignature() { // Deletes a signature
    const pageDocument  = document.getElementById("otb-options-iframe").contentDocument;
    const otb_sigListbox  = pageDocument.getElementById("otb_sigListbox");
    const selectedItem  = otb_sigListbox.selectedItem;
    const stringBundle  = document.getElementById("otbstrings");

    if(selectedItem && confirm(stringBundle.getString("otb_deleteConfirmation")))  {     // If an item is selected and the deletion is confirmed
        otb_sigListbox.removeChild(selectedItem);
    }
}

function otb_editSignature() { // Edits a signature
    const pageDocument = document.getElementById("otb-options-iframe").contentDocument;
    const otb_sigListbox = pageDocument.getElementById("otb_sigListbox");
    const selectedItem = otb_sigListbox.selectedItem;

    if(selectedItem) {  // If an item is selected
        window.openDialog("chrome://orkutbar/content/options/dlg_signature.xul", "otb-signature-dialog", "centerscreen,chrome,modal", "edit", selectedItem.label, selectedItem.value);

        if(otb_description) { // If the description is set
            selectedItem.label = otb_description;
            selectedItem.value = otb_signature;
            otb_sigListbox.ensureElementIsVisible(selectedItem);
        }
    }
}

function otb_initializeGeneral() { // Initializes the general page
	return true;
}

function otb_initializeOptions() { // Initializes the options dialog box
    const preferencesService = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("");
    const selectedPage       = document.getElementById("otb_page-list").selectedItem.getAttribute("value");

    if(selectedPage.indexOf("general") != -1) { otb_initializeGeneral(); }
    else if(selectedPage.indexOf("signatures") != -1) { otb_initializeSignature(); }
}

function otb_initializeSignature() { // Initializes the signatures
    const pageDocument       = document.getElementById("otb-options-iframe").contentDocument;
    const preferencesService = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("");
    const otb_sigListbox       = pageDocument.getElementById("otb_sigListbox");

    var description      = null;    var descriptionValue = null;
    var signature        = null;    var signatureValue   = null;
    var listItem         = null;	var signatureCount   = 0;

    if(typeof otb_optionsDataInteger["otb.singatures.count"] != "undefined") {     // If the user signatures count preference is set
        signatureCount = otb_optionsDataInteger["otb.singatures.count"];
    }
    else if(preferencesService.prefHasUserValue("otb.singatures.count")) {
        signatureCount = preferencesService.getIntPref("otb.singatures.count");
    }

    for(var i = 1; i <= signatureCount; i++) { // Loop through the possible signatures
	    description = "otb.opt.sig." + i + ".description";
	    signature   = "otb.opt.sig." + i + ".signature";

        if(typeof otb_optionsDataString[description] != "undefined") { // If the description is set
            descriptionValue = otb_optionsDataString[description].trim();
        }
        else if(preferencesService.prefHasUserValue(description)) {
	        descriptionValue = preferencesService.getComplexValue(description, Components.interfaces.nsISupportsString).data.trim();
        }
        else  { descriptionValue = null; }

        if(typeof otb_optionsDataString[signature] != "undefined") {   // If the user signature
            signatureValue = otb_optionsDataString[signature].trim();
        }
        else if(preferencesService.prefHasUserValue(signature)) {
	        signatureValue = preferencesService.getComplexValue(signature, Components.interfaces.nsISupportsString).data.trim();
        }
        else  { signatureValue = null; }

        if(descriptionValue) { listItem = otb_sigListbox.appendItem(descriptionValue, signatureValue);  } // If the description is set
    }
	otbSelectItem();
}

function otb_moveDown() { // Moves the selected item down
    const pageDocument   = document.getElementById("otb-options-iframe").contentDocument;
    const otb_sigListbox   = pageDocument.getElementById("otb_sigListbox");
    const selectedIndex  = otb_sigListbox.selectedIndex;
    const selectedItem   = otb_sigListbox.selectedItem;
    const signaturesCount = otb_sigListbox.getRowCount();

    if(selectedItem && selectedIndex != signaturesCount - 1) { // If an item is selected and it is not at the bottom
        otb_sigListbox.selectItem(otb_sigListbox.insertBefore(selectedItem, otb_sigListbox.getNextItem(selectedItem, 2)));
    }
}

function otbr_moveUp() { // Moves the selected item up
    const pageDocument  = document.getElementById("otb-options-iframe").contentDocument;
    const otb_sigListbox  = pageDocument.getElementById("otb_sigListbox");
    const selectedIndex = otb_sigListbox.selectedIndex;
    const selectedItem  = otb_sigListbox.selectedItem;

    if(selectedItem && selectedIndex != 0) {    // If an item is selected and it is not at the top
        otb_sigListbox.selectItem(otb_sigListbox.insertBefore(selectedItem, otb_sigListbox.getPreviousItem(selectedItem, 1)));
    }
}

function otbSelectItem() {
    const pageDocument  = document.getElementById("otb-options-iframe").contentDocument;
    const otb_sigListbox  = pageDocument.getElementById("otb_sigListbox");
	var selIdx = otb_sigListbox.selectedIndex;
    var rowCount = otb_sigListbox.getRowCount();
            
    pageDocument.getElementById("up").disabled = selIdx <= 0;
    pageDocument.getElementById("down").disabled = selIdx < 0 || selIdx >= rowCount - 1;
    pageDocument.getElementById("delete").disabled = selIdx < 0;
    pageDocument.getElementById("edit").disabled = selIdx < 0;
}
